@@ -1,5 +1,7 @@
 use super::*;
 
+mod deprecated;
+
 impl AWSClusterSpec {
     pub fn region(&self) -> Option<&str> {
         self.region.as_deref()
@@ -34,48 +36,46 @@ impl AWSCluster {
     }
 
     #[must_use]
-    pub fn set_region(self, region: impl ToString) -> Self {
-        Self {
-            spec: AWSClusterSpec {
-                region: Some(region.to_string()),
-                ..self.spec
-            },
-            ..self
-        }
+    pub fn region(mut self, region: impl ToString) -> Self {
+        self.spec.region = Some(region.to_string());
+        self
     }
 
     #[must_use]
-    pub fn set_sshkey(self, sshkey: impl ToString) -> Self {
-        Self {
-            spec: AWSClusterSpec {
-                ssh_key_name: Some(sshkey.to_string()),
-                ..self.spec
-            },
-            ..self
-        }
+    pub fn sshkey(mut self, sshkey: impl ToString) -> Self {
+        self.spec.ssh_key_name = Some(sshkey.to_string());
+        self
     }
 
     #[must_use]
-    pub fn set_vpc_cidr_block(self, vpc_cidr_block: impl ToString) -> Self {
-        let vpc_cidr_block = vpc_cidr_block.to_string();
-        let network = self.spec.network.unwrap_or_default();
-        let vpc = network.vpc.unwrap_or_default();
-        let vpc = VPCSpec {
-            cidr_block: Some(vpc_cidr_block),
-            ..vpc
-        };
-        let network = NetworkSpec {
-            vpc: Some(vpc),
-            ..network
-        };
+    pub fn vpc_cidr_block(mut self, cidr_block: impl ToString) -> Self {
+        let cidr_block = cidr_block.to_string();
+        let mut network = self.spec.network.unwrap_or_default();
+        let mut vpc = network.vpc.unwrap_or_default();
+        vpc.cidr_block = Some(cidr_block);
+        network.vpc = Some(vpc);
+        self.spec.network = Some(network);
 
-        Self {
-            spec: AWSClusterSpec {
-                network: Some(network),
-                ..self.spec
-            },
-            ..self
-        }
+        // let vpc_cidr_block = vpc_cidr_block.to_string();
+        // let network = self.spec.network.unwrap_or_default();
+        // let vpc = network.vpc.unwrap_or_default();
+        // let vpc = VPCSpec {
+        //     cidr_block: Some(vpc_cidr_block),
+        //     ..vpc
+        // };
+        // let network = NetworkSpec {
+        //     vpc: Some(vpc),
+        //     ..network
+        // };
+
+        // Self {
+        //     spec: AWSClusterSpec {
+        //         network: Some(network),
+        //         ..self.spec
+        //     },
+        //     ..self
+        // }
+        self
     }
 
     pub fn add_subnet(&mut self, availability_zone: &str, cidr_block: &str, is_public: bool) {
@@ -104,4 +104,18 @@ impl AWSCluster {
             ..self
         }
     }
+
+    pub fn bastion(self) -> Self {
+        Self {
+            spec: AWSClusterSpec {
+                bastion: Some(Bastion {
+                    enabled: Some(true),
+                    allowed_cidr_blocks: vec!["0.0.0.0/0".to_string()],
+                    ..Bastion::default()
+                }),
+                ..self.spec
+            },
+            ..self
+        }
+    }
 }
